/* Include prototypes for all files */
/*
 * $Id: protos.h,v 1.1.1.1 2004/11/10 17:21:47 sasha Exp $
 */
#include "command.pro"
#include "graphics.pro"
#include "grkelot.pro"
#include "main.pro"
#include "menubar.pro"
#include "misc.pro"
#include "netdisp.pro"
#include "rmemset.pro"
#include "screen.pro"
#include "thai.pro"
# include "scrollbar.pro"
#ifdef UTMP_SUPPORT
#include "utmp.pro"
#endif
#include "xdefaults.pro"
#include "pixmap.pro"
